@@ -1,7 +1,6 @@
 import logging
 import os
 import re
-from collections import defaultdict
 from functools import lru_cache
 
 import psycopg2
@@ -12,112 +11,23 @@ from firepit.exceptions import DuplicateTable
 from firepit.exceptions import InvalidAttr
 from firepit.exceptions import UnexpectedError
 from firepit.exceptions import UnknownViewname
+from firepit.pgcommon import (CHECK_FOR_COMMON_SCHEMA, COLUMNS_TABLE,
+                              CHECK_FOR_QUERIES_TABLE, INTERNAL_TABLES,
+                              LIKE_BIN, MATCH_BIN, MATCH_FUN, SUBNET_FUN,
+                              _rewrite_view_def, _infer_type)
 from firepit.splitter import SqlWriter
 from firepit.sqlstorage import DB_VERSION
 from firepit.sqlstorage import SqlStorage
-from firepit.sqlstorage import infer_type
 from firepit.sqlstorage import validate_name
 
 logger = logging.getLogger(__name__)
 
 
-CHECK_FOR_QUERIES_TABLE = (
-    "SELECT (EXISTS (SELECT *"
-    " FROM INFORMATION_SCHEMA.TABLES"
-    " WHERE TABLE_SCHEMA = %s"
-    " AND  TABLE_NAME = '__queries'))"
-)
-
-CHECK_FOR_COMMON_SCHEMA = (
-    "SELECT routines.routine_name"
-    " FROM information_schema.routines"
-    " WHERE routines.specific_schema = 'firepit_common'"
-)
-
-MATCH_FUN = '''CREATE FUNCTION firepit_common.match(pattern TEXT, value TEXT)
-RETURNS boolean AS $$
-    SELECT regexp_match(value, pattern) IS NOT NULL;
-$$ LANGUAGE SQL;'''
-
-MATCH_BIN = '''CREATE FUNCTION firepit_common.match_bin(pattern TEXT, value TEXT)
-RETURNS boolean AS $$
-    SELECT regexp_match(convert_from(decode(value, 'base64'), 'UTF8'), pattern) IS NOT NULL;
-$$ LANGUAGE SQL;'''
-
-LIKE_BIN = '''CREATE FUNCTION firepit_common.like_bin(pattern TEXT, value TEXT)
-RETURNS boolean AS $$
-    SELECT convert_from(decode(value, 'base64'), 'UTF8') LIKE pattern;
-$$ LANGUAGE SQL;'''
-
-SUBNET_FUN = '''CREATE FUNCTION firepit_common.in_subnet(addr TEXT, net TEXT)
-RETURNS boolean AS $$
-    SELECT addr::inet <<= net::inet;
-$$ LANGUAGE SQL;'''
-
-METADATA_TABLE = ('CREATE UNLOGGED TABLE IF NOT EXISTS "__metadata" '
-                  '(name TEXT, value TEXT)')
-
-SYMTABLE = ('CREATE UNLOGGED TABLE IF NOT EXISTS "__symtable" '
-            '(name TEXT, type TEXT, appdata TEXT,'
-            ' UNIQUE(name))')
-
-QUERIES_TABLE = ('CREATE UNLOGGED TABLE IF NOT EXISTS "__queries" '
-                 '(sco_id TEXT, query_id TEXT)')
-
-CONTAINS_TABLE = ('CREATE UNLOGGED TABLE IF NOT EXISTS "__contains" '
-                  '(source_ref TEXT, target_ref TEXT, x_firepit_rank INTEGER,'
-                  ' UNIQUE(source_ref, target_ref));')
-
-COLUMNS_TABLE = ('CREATE UNLOGGED TABLE IF NOT EXISTS "__columns" '
-                 '(otype TEXT, path TEXT, shortname TEXT, dtype TEXT,'
-                 ' UNIQUE(otype, path));')
-
-# Bootstrap some common SDO tables
-ID_TABLE = ('CREATE UNLOGGED TABLE "identity" ('
-            ' "id" TEXT UNIQUE,'
-            ' "identity_class" TEXT,'
-            ' "name" TEXT,'
-            ' "created" TEXT,'
-            ' "modified" TEXT'
-            ')')
-
-OD_TABLE = ('CREATE UNLOGGED TABLE "observed-data" ('
-            ' "id" TEXT UNIQUE,'
-            ' "created_by_ref" TEXT,'
-            ' "created" TEXT,'
-            ' "modified" TEXT,'
-            ' "first_observed" TEXT,'
-            ' "last_observed" TEXT,'
-            ' "number_observed" BIGINT'
-            ')')
-
-INTERNAL_TABLES = [
-    METADATA_TABLE,
-    SYMTABLE,
-    QUERIES_TABLE,
-    CONTAINS_TABLE,
-    COLUMNS_TABLE,
-    ID_TABLE,
-    OD_TABLE,
-]
-
-
 def get_storage(url, session_id):
     dbname = url.path.lstrip('/')
     return PgStorage(dbname, url.geturl(), session_id)
 
 
-def _infer_type(key, value):
-    # PostgreSQL type specializations
-    rtype = None
-    if isinstance(value, bool):
-        rtype = 'BOOLEAN'
-    else:
-        # Fall back to defaults
-        rtype = infer_type(key, value)
-    return rtype
-
-
 # PostgreSQL defaults for COPY text format
 SEP = '\t'
 TEXT_ESCAPE_TABLE = str.maketrans({
@@ -192,60 +102,6 @@ class TuplesToTextIO:
         return result
 
 
-def _rewrite_view_def(viewname, viewdef):
-    if viewdef:
-        stmt = viewdef['definition'].rstrip(';').replace('\n', ' ')
-
-        # PostgreSQL will "expand" the original "*" to the columns
-        # that existed at that time.  We need to get the star back, to
-        # match SQLite3's behavior.
-        logger.debug('%s original:  %s', viewname, stmt)
-        stmt = _rewrite_query(stmt)
-        logger.debug('%s rewritten: %s', viewname, stmt)
-        return stmt
-
-    # Must be a table
-    return f'SELECT * FROM "{viewname}"'
-
-
-def _rewrite_query(qry):
-    parts = qry.split('UNION')
-    new_parts = []
-    for part in parts:
-        new_parts.append(_rewrite_select(part).strip())
-    return ' UNION '.join(new_parts)
-
-
-def _rewrite_select(stmt):
-    p = r"SELECT (DISTINCT )?(\"observed-data\".[\w_]+\W+)?(\"?[\w\d_-]+\"?\.\"?['\w\d\._-]+\"?,?\W+)+FROM"
-    m = re.search(p, stmt)
-    if m:
-        matched = m.group(0).split()[1:-1]  # Drop SELECT and FROM
-        if matched[0].strip() == 'DISTINCT':
-            distinct = 'DISTINCT '
-        else:
-            distinct = ''
-        data = defaultdict(list)
-        order = []
-        for i in matched:
-            table, _, column = i.partition('.')
-            column = column.rstrip(',')
-            data[table].append(column)
-            if table not in order and not table.startswith('DISTINCT'):
-                order.append(table)
-        new_cols = []
-        for table in order:
-            num = len(data[table])
-            if num > 1:
-                new_cols.append(f'{table}.*')
-            elif num == 1:
-                col = data[table][0]
-                new_cols.append(f'{table}.{col}')
-        repl = f'SELECT {distinct}' + ', '.join(new_cols) + ' FROM'
-        stmt = re.sub(p, repl, stmt, count=1)
-    return stmt
-
-
 class PgStorage(SqlStorage):
     def __init__(self, dbname, url, session_id=None):
         super().__init__()
